| author.ready4class_constructor | R Documentation |
author.ready4class_constructor() is an author method that authors and saves files to local or remote locations. This method is implemented for the Class constructor table The function returns X (Class prototype lookup table).
author.ready4class_manifest() is an author method that authors and saves files to local or remote locations. This method is implemented for the Class creation manifest The function is called for its side effects and does not return a value.
author.ready4class_pt_lup() is an author method that authors and saves files to local or remote locations. This method is implemented for the Class prototype lookup table The function returns X (Class prototype lookup table).
author.ready4class_constructor(
x,
dev_pkg_ns_1L_chr = ready4fun::get_dev_pkg_nm(),
name_pfx_1L_chr = paste0(ready4fun::get_dev_pkg_nm(), "_"),
output_dir_1L_chr = "R",
delete_cdn_ptrn_chr = NA_character_,
file_exists_cdn_1L_chr = "overwrite",
init_class_pt_lup = NULL,
nss_to_ignore_chr = NA_character_,
req_pkgs_chr = NA_character_,
class_in_cache_cdn_1L_chr = "stop",
abbreviations_lup,
fn_types_lup,
object_type_lup
)
## S4 method for signature 'ready4class_constructor'
author(
x,
dev_pkg_ns_1L_chr = ready4fun::get_dev_pkg_nm(),
name_pfx_1L_chr = paste0(ready4fun::get_dev_pkg_nm(), "_"),
output_dir_1L_chr = "R",
delete_cdn_ptrn_chr = NA_character_,
file_exists_cdn_1L_chr = "overwrite",
init_class_pt_lup = NULL,
nss_to_ignore_chr = NA_character_,
req_pkgs_chr = NA_character_,
class_in_cache_cdn_1L_chr = "stop",
abbreviations_lup,
fn_types_lup,
object_type_lup
)
author.ready4class_manifest(
x,
init_class_pt_lup = NULL,
key_1L_chr = Sys.getenv("DATAVERSE_KEY"),
list_generics_1L_lgl = T,
nss_to_ignore_chr = NA_character_,
req_pkgs_chr = NA_character_,
self_serve_1L_lgl = F,
self_serve_fn_ls = NULL
)
## S4 method for signature 'ready4class_manifest'
author(
x,
init_class_pt_lup = NULL,
key_1L_chr = Sys.getenv("DATAVERSE_KEY"),
list_generics_1L_lgl = T,
nss_to_ignore_chr = NA_character_,
req_pkgs_chr = NA_character_,
self_serve_1L_lgl = F,
self_serve_fn_ls = NULL
)
author.ready4class_pt_lup(
x,
row_idx_1L_int,
make_tb,
dev_pkg_ns_1L_chr,
name_pfx_1L_chr,
output_dir_1L_chr,
file_exists_cdn_1L_chr,
nss_to_ignore_chr = NA_character_,
req_pkgs_chr = NA_character_,
class_in_cache_cdn_1L_chr = "stop",
abbreviations_lup,
fn_types_lup,
object_type_lup,
consent_1L_chr = NULL
)
## S4 method for signature 'ready4class_pt_lup'
author(
x,
row_idx_1L_int,
make_tb,
dev_pkg_ns_1L_chr,
name_pfx_1L_chr,
output_dir_1L_chr,
file_exists_cdn_1L_chr,
nss_to_ignore_chr = NA_character_,
req_pkgs_chr = NA_character_,
class_in_cache_cdn_1L_chr = "stop",
abbreviations_lup,
fn_types_lup,
object_type_lup,
consent_1L_chr = NULL
)
x |
An instance of |
dev_pkg_ns_1L_chr |
Development package namespace (a character vector of length one) |
name_pfx_1L_chr |
Name prefix (a character vector of length one) |
output_dir_1L_chr |
Output directory (a character vector of length one) |
delete_cdn_ptrn_chr |
Delete condition pattern (a character vector), Default: 'NA' |
file_exists_cdn_1L_chr |
File exists condition (a character vector of length one) |
init_class_pt_lup |
Initial class prototype (a lookup table), Default: NULL |
nss_to_ignore_chr |
Namespaces to ignore (a character vector), Default: 'NA' |
req_pkgs_chr |
Require packages (a character vector), Default: 'NA' |
class_in_cache_cdn_1L_chr |
Class in cache condition (a character vector of length one), Default: 'stop' |
abbreviations_lup |
Abbreviations (a lookup table) |
fn_types_lup |
Function types (a lookup table) |
object_type_lup |
Object type (a lookup table) |
key_1L_chr |
Key (a character vector of length one), Default: Sys.getenv("DATAVERSE_KEY") |
list_generics_1L_lgl |
List generics (a logical vector of length one), Default: T |
self_serve_1L_lgl |
Self serve (a logical vector of length one), Default: F |
self_serve_fn_ls |
Self serve (a list of functions), Default: NULL |
row_idx_1L_int |
Row index (an integer vector of length one) |
make_tb |
Make (a tibble) |
consent_1L_chr |
Consent (a character vector of length one), Default: NULL |
X (Class prototype lookup table)
X (ready4 submodule class for encapsulating the metadata required for package set-up.)
X (Class prototype lookup table)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.