| get_class_fl_nms | R Documentation |
get_class_fl_nms() is a Get function that extracts data from an object. Specifically, this function implements an algorithm to get class file names. The function returns Class file names (a character vector).
get_class_fl_nms(class_names_chr, s3_1L_lgl = T, output_dir_1L_chr = NA)
class_names_chr |
Class names (a character vector) |
s3_1L_lgl |
S3 (a logical vector of length one), Default: T |
output_dir_1L_chr |
Output directory (a character vector of length one), Default: NA |
Class file names (a character vector)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.