| get_nms_of_curr_gnrcs | R Documentation |
get_nms_of_curr_gnrcs() is a Get function that extracts data from an object. Specifically, this function implements an algorithm to get names of current generics. The function returns Names of current generics (a list).
get_nms_of_curr_gnrcs(req_pkgs_chr, generic_1L_chr)
req_pkgs_chr |
Require packages (a character vector) |
generic_1L_chr |
Generic (a character vector of length one) |
Names of current generics (a list)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.