make_alg_to_write_gtr_str_mthds: Make algorithm to write getter setter methods

make_alg_to_write_gtr_str_mthdsR Documentation

Make algorithm to write getter setter methods

Description

make_alg_to_write_gtr_str_mthds() is a Make function that creates a new R object. Specifically, this function implements an algorithm to make algorithm to write getter setter methods. The function is called for its side effects and does not return a value.

Usage

make_alg_to_write_gtr_str_mthds(
  class_nm_1L_chr,
  parent_cls_nm_1L_chr,
  print_gtrs_strs_1L_lgl,
  output_dir_1L_chr,
  nss_to_ignore_chr,
  req_pkgs_chr,
  parent_ns_ls
)

Arguments

class_nm_1L_chr

Class name (a character vector of length one)

parent_cls_nm_1L_chr

Parent class name (a character vector of length one)

print_gtrs_strs_1L_lgl

Print getters setters (a logical vector of length one)

output_dir_1L_chr

Output directory (a character vector of length one)

nss_to_ignore_chr

Namespaces to ignore (a character vector)

req_pkgs_chr

Require packages (a character vector)

parent_ns_ls

Parent namespace (a list)

Value

Algorithm to write getter setter (methods)


ready4-dev/ready4class documentation built on April 22, 2024, 8:30 a.m.