make_fn_pt_to_check_r3_cls_inhtc: Make function prototype to check ready4 submodule class...

make_fn_pt_to_check_r3_cls_inhtcR Documentation

Make function prototype to check ready4 submodule class inheritance

Description

make_fn_pt_to_check_r3_cls_inhtc() is a Make function that creates a new R object. Specifically, this function implements an algorithm to make function prototype to check ready4 submodule class inheritance. The function is called for its side effects and does not return a value.

Usage

make_fn_pt_to_check_r3_cls_inhtc(class_nm_1L_chr, s3_validator_ls)

Arguments

class_nm_1L_chr

Class name (a character vector of length one)

s3_validator_ls

S3 validator (a list)

Value

Function prototype to check ready4 submodule class (an inheritance)


ready4-dev/ready4class documentation built on April 22, 2024, 8:30 a.m.