make_fn_pt_to_make_unvld_r3_cls_inst: Make function prototype to make unvalidated ready4 submodule...

make_fn_pt_to_make_unvld_r3_cls_instR Documentation

Make function prototype to make unvalidated ready4 submodule class instance

Description

make_fn_pt_to_make_unvld_r3_cls_inst() is a Make function that creates a new R object. Specifically, this function implements an algorithm to make function prototype to make unvalidated ready4 submodule class instance. The function is called for its side effects and does not return a value.

Usage

make_fn_pt_to_make_unvld_r3_cls_inst(
  type_1L_chr,
  pt_chkr_pfx_1L_chr,
  pt_ns_1L_chr,
  class_nm_1L_chr,
  s3_prototype_ls
)

Arguments

type_1L_chr

Type (a character vector of length one)

pt_chkr_pfx_1L_chr

Prototype checker prefix (a character vector of length one)

pt_ns_1L_chr

Prototype namespace (a character vector of length one)

class_nm_1L_chr

Class name (a character vector of length one)

s3_prototype_ls

S3 prototype (a list)

Value

Function prototype to make unvalidated ready4 submodule class (an instance)


ready4-dev/ready4class documentation built on April 22, 2024, 8:30 a.m.