View source: R/C3_ready4class_pt_lup.R
| make_new_ready4class_pt_lup | R Documentation |
Create a new unvalidated instance of the Class prototype lookup table
make_new_ready4class_pt_lup(x)
x |
A prototype for the Class prototype lookup table |
Class prototype lookup table
An unvalidated instance of the Class prototype lookup table
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.