| make_fn_pt_to_make_vld_r3_cls_inst | R Documentation |
make_fn_pt_to_make_vld_r3_cls_inst() is a Make function that creates a new R object. Specifically, this function implements an algorithm to make function prototype to make valid ready4 submodule class instance. The function is called for its side effects and does not return a value.
make_fn_pt_to_make_vld_r3_cls_inst(
type_1L_chr,
class_nm_1L_chr,
s3_prototype_ls,
min_max_vals_dbl,
start_end_vals_dbl,
vals_ls,
asserts_ls = NULL,
dev_pkg_ns_1L_chr = ready4fun::get_dev_pkg_nm()
)
type_1L_chr |
Type (a character vector of length one) |
class_nm_1L_chr |
Class name (a character vector of length one) |
s3_prototype_ls |
S3 prototype (a list) |
min_max_vals_dbl |
Minimum maximum values (a double vector) |
start_end_vals_dbl |
Start end values (a double vector) |
vals_ls |
Values (a list) |
asserts_ls |
Asserts (a list), Default: NULL |
dev_pkg_ns_1L_chr |
Development package namespace (a character vector of length one), Default: ready4fun::get_dev_pkg_nm() |
Function prototype to make valid ready4 submodule class (an instance)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.